@@ -2,10 +2,6 @@ import config from 'config';
 import checkDiskSpace from 'check-disk-space';
 import { log } from '@tamanu/shared/services/logging';
 
-// Convert value in config to bytes (prefer decimal over binary conversion)
-const FREE_SPACE_REQUIRED =
-  parseInt(config.disk.freeSpaceRequired.gigabytesForUploadingDocuments, 10) * 1000000000;
-
 // Wraps a module function and calls it with parameters from config.
 // Returns the available disk space in bytes.
 export const getFreeDiskSpace = async () => {
@@ -19,10 +15,15 @@ export const getFreeDiskSpace = async () => {
 };
 
 // Tries to read free disk space and compares it to minimum required from config.
-export const canUploadAttachment = async () => {
+export const canUploadAttachment = async settings => {
+  const gigabytesForUploadingDocuments = await settings.get(
+    'disk.freeSpaceRequired.gigabytesForUploadingDocuments',
+  );
+  // Convert value in settings to bytes (prefer decimal over binary conversion)
+  const freeSpaceRequired = Number.parseInt(gigabytesForUploadingDocuments, 10) * 1_000_000_000;
   const freeDiskSpace = await getFreeDiskSpace();
 
-  if (!freeDiskSpace || freeDiskSpace < FREE_SPACE_REQUIRED) {
+  if (!freeDiskSpace || freeDiskSpace < freeSpaceRequired) {
     return false;
   }
 
